# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.get_workspaces200_response_items_inner import GetWorkspaces200ResponseItemsInner

class TestGetWorkspaces200ResponseItemsInner(unittest.TestCase):
    """GetWorkspaces200ResponseItemsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetWorkspaces200ResponseItemsInner:
        """Test GetWorkspaces200ResponseItemsInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetWorkspaces200ResponseItemsInner`
        """
        model = GetWorkspaces200ResponseItemsInner()
        if include_optional:
            return GetWorkspaces200ResponseItemsInner(
                id = '',
                name = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                member_count = 1.337
            )
        else:
            return GetWorkspaces200ResponseItemsInner(
                id = '',
                name = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                member_count = 1.337,
        )
        """

    def testGetWorkspaces200ResponseItemsInner(self):
        """Test GetWorkspaces200ResponseItemsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
