# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.get_panel_surveys200_response import GetPanelSurveys200Response

class TestGetPanelSurveys200Response(unittest.TestCase):
    """GetPanelSurveys200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetPanelSurveys200Response:
        """Test GetPanelSurveys200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetPanelSurveys200Response`
        """
        model = GetPanelSurveys200Response()
        if include_optional:
            return GetPanelSurveys200Response(
                items = [
                    keplar_api.models.admin_panel_invite.AdminPanelInvite(
                        id = '', 
                        name = '', 
                        code = '', 
                        status = 'PREVIEW', 
                        config = keplar_api.models.invite_config.InviteConfig(), 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        project = keplar_api.models.admin_panel_invite_project.AdminPanelInvite_project(
                            id = '', 
                            name = '', 
                            created_by = keplar_api.models.admin_panel_invite_project_created_by.AdminPanelInvite_project_createdBy(
                                id = '', 
                                name = '', 
                                email = '', ), ), )
                    ],
                total = 1.337,
                page = 1.337,
                limit = 1.337
            )
        else:
            return GetPanelSurveys200Response(
                items = [
                    keplar_api.models.admin_panel_invite.AdminPanelInvite(
                        id = '', 
                        name = '', 
                        code = '', 
                        status = 'PREVIEW', 
                        config = keplar_api.models.invite_config.InviteConfig(), 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        project = keplar_api.models.admin_panel_invite_project.AdminPanelInvite_project(
                            id = '', 
                            name = '', 
                            created_by = keplar_api.models.admin_panel_invite_project_created_by.AdminPanelInvite_project_createdBy(
                                id = '', 
                                name = '', 
                                email = '', ), ), )
                    ],
                total = 1.337,
                page = 1.337,
                limit = 1.337,
        )
        """

    def testGetPanelSurveys200Response(self):
        """Test GetPanelSurveys200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
