# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.get_projects200_response import GetProjects200Response

class TestGetProjects200Response(unittest.TestCase):
    """GetProjects200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetProjects200Response:
        """Test GetProjects200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetProjects200Response`
        """
        model = GetProjects200Response()
        if include_optional:
            return GetProjects200Response(
                items = [
                    keplar_api.models.project_summary_with_analytics.ProjectSummaryWithAnalytics()
                    ],
                total = 1.337,
                page = 1.337,
                limit = 1.337
            )
        else:
            return GetProjects200Response(
                items = [
                    keplar_api.models.project_summary_with_analytics.ProjectSummaryWithAnalytics()
                    ],
                total = 1.337,
                page = 1.337,
                limit = 1.337,
        )
        """

    def testGetProjects200Response(self):
        """Test GetProjects200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
