# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.vapi_assistant_config_artifact_plan import VapiAssistantConfigArtifactPlan

class TestVapiAssistantConfigArtifactPlan(unittest.TestCase):
    """VapiAssistantConfigArtifactPlan unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VapiAssistantConfigArtifactPlan:
        """Test VapiAssistantConfigArtifactPlan
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VapiAssistantConfigArtifactPlan`
        """
        model = VapiAssistantConfigArtifactPlan()
        if include_optional:
            return VapiAssistantConfigArtifactPlan(
                recording_format = 'mp3',
                video_recording_enabled = True
            )
        else:
            return VapiAssistantConfigArtifactPlan(
        )
        """

    def testVapiAssistantConfigArtifactPlan(self):
        """Test VapiAssistantConfigArtifactPlan"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
