# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.invite_response_with_metadata import InviteResponseWithMetadata

class TestInviteResponseWithMetadata(unittest.TestCase):
    """InviteResponseWithMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InviteResponseWithMetadata:
        """Test InviteResponseWithMetadata
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InviteResponseWithMetadata`
        """
        model = InviteResponseWithMetadata()
        if include_optional:
            return InviteResponseWithMetadata(
                id = '',
                attributes = [
                    keplar_api.models.invite_response_with_metadata_attributes_inner.InviteResponseWithMetadata_attributes_inner(
                        id = '', 
                        value = '', 
                        attribute_kind_id = '', 
                        evidence = keplar_api.models.invite_response_with_metadata_attributes_inner_evidence.InviteResponseWithMetadata_attributes_inner_evidence(
                            verbatims = '', 
                            confidence = 1.337, 
                            message_index = 1.337, ), )
                    ]
            )
        else:
            return InviteResponseWithMetadata(
                id = '',
                attributes = [
                    keplar_api.models.invite_response_with_metadata_attributes_inner.InviteResponseWithMetadata_attributes_inner(
                        id = '', 
                        value = '', 
                        attribute_kind_id = '', 
                        evidence = keplar_api.models.invite_response_with_metadata_attributes_inner_evidence.InviteResponseWithMetadata_attributes_inner_evidence(
                            verbatims = '', 
                            confidence = 1.337, 
                            message_index = 1.337, ), )
                    ],
        )
        """

    def testInviteResponseWithMetadata(self):
        """Test InviteResponseWithMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
